import 'dart:math';

import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/models/ProductModel.dart';
import 'package:apus_drones_mobile/screens/Appbar.dart';
import 'package:apus_drones_mobile/services/ProductService.dart';
import 'package:apus_drones_mobile/widgets/AddToCart.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:apus_drones_mobile/widgets/QuantityChangerChip.dart';
import 'package:apus_drones_mobile/widgets/ProductCarousel.dart';
import 'package:flutter/material.dart';

class CustomerProductDetailScreen extends StatefulWidget {
  static final String routeName = 'customer/productDetail';
  final int productId;
  CustomerProductDetailScreen({Key? key, required this.productId})
      : super(key: key);

  @override
  _CustomerProductDetailScreenState createState() =>
      _CustomerProductDetailScreenState();
}

class _CustomerProductDetailScreenState
    extends State<CustomerProductDetailScreen> {
  int _quantity = 1;
  late ProductModel product;
  ProductService service = ProductService();
  bool productRecived = false;

  void _fetchProduct() {
    service.getProduct(widget.productId).then((p) => setState(() {
          product = p;
          productRecived = true;
        }));
  }

  @override
  void initState() {
    super.initState();
    productRecived = false;
    _fetchProduct();
  }

  @override
  Widget build(BuildContext context) {
    return render();
  }

  Scaffold render() {
    if (productRecived) {
      final _product = product;
      final maxQuantity = _product.quantity;
      return Scaffold(
        appBar: Appbar(
          title: _product.name,
        ),
        bottomNavigationBar: BotNavBar(role: UserType.CUSTOMER),
        body: Container(
          padding: EdgeInsets.only(top: 35),
          child: SingleChildScrollView(
            child: Center(
              child: Padding(
                padding: EdgeInsets.symmetric(vertical: 20, horizontal: 20),
                child: Column(
                  children: [
                    ProductCarousel(
                        productImages: _product.imagesUrls, height: 250),
                    SizedBox(height: 20),
                    Text(
                      _product.name,
                      style:
                          TextStyle(fontSize: 16, fontWeight: FontWeight.bold),
                    ),
                    SizedBox(height: 20),
                    Text(_product.description),
                    SizedBox(height: 20),
                    Container(
                      alignment: Alignment.center,
                      width: 365,
                      child: Row(
                        mainAxisAlignment: MainAxisAlignment.spaceBetween,
                        children: [
                          QuantityChangerChip(
                            quantity: _quantity,
                            minQuantity: 1,
                            maxQuantity: maxQuantity,
                            onTapMinus: () {
                              setState(() {
                                _quantity = max(_quantity - 1, 1);
                              });
                            },
                            onTapPlus: () {
                              setState(() {
                                _quantity = min(_quantity + 1, maxQuantity);
                              });
                            },
                          ),
                          SizedBox(width: 20),
                          AddToCart(
                            product: product,
                            quantity: _quantity,
                          ),
                        ],
                      ),
                    )
                  ],
                ),
              ),
            ),
          ),
        ),
      );
    }
    return Scaffold();
  }
}
