import 'package:apus_drones_mobile/constants/Constants.dart';
import 'package:apus_drones_mobile/models/CustomerModel.dart';
import 'package:apus_drones_mobile/screens/Appbar.dart';
import 'package:apus_drones_mobile/services/CustomerService.dart';
import 'package:apus_drones_mobile/widgets/UserDisplayedProperty.dart';
import 'package:flutter/material.dart';

class CustomerProfile extends StatefulWidget {
  const CustomerProfile({Key? key}) : super(key: key);

  @override
  _CustomerProfileState createState() => _CustomerProfileState();
}

class _CustomerProfileState extends State<CustomerProfile> {
  CustomerModel? customer;
  CustomerService customerService = CustomerService();

  _CustomerProfileState() {
    _loadProfile();
  }

  _loadProfile() {
    customerService.getProfile().then((customer) => onCustomerData(customer));
  }

  onCustomerData(CustomerModel data) {
    this.setState(() {
      this.customer = data;
    });
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
        appBar: Appbar(
          title: "Cliente - ${this.customer?.name ?? ''}",
        ),
        body: Column(
          children: [
            Padding(
              padding: EdgeInsets.all(20),
              child:
                  Row(mainAxisAlignment: MainAxisAlignment.center, children: [
                Container(
                  width: 140.0,
                  height: 140.0,
                  decoration: BoxDecoration(
                      shape: BoxShape.circle,
                      border: Border.all(width: 3.0, color: Colors.grey),
                      image: DecorationImage(
                          fit: BoxFit.fill,
                          image: NetworkImage(
                              customer?.avatarUrl ?? IMG_NO_PHOTO))),
                ),
              ]),
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  "${customer?.name}",
                  style: TextStyle(fontSize: 24, fontWeight: FontWeight.bold),
                )
              ],
            ),
            Row(
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Text(
                  "${customer?.email}",
                  style: TextStyle(fontSize: 16),
                )
              ],
            ),
            Padding(
                padding: EdgeInsets.all(16),
                child: Padding(
                  padding: EdgeInsets.only(top: 24),
                  child: Column(
                    children: [
                      Padding(
                        padding: EdgeInsets.all(8),
                        child: UserDisplayedProperty<String?>(
                          name: "CPF / CNPJ",
                          value: customer?.cpfCnpj,
                        ),
                      ),
                      Padding(
                        padding: EdgeInsets.all(8),
                        child: UserDisplayedProperty<String?>(
                          name: "Endereço",
                          value: (customer?.addresses?.isEmpty ?? true
                                  ? null
                                  : customer?.addresses?.first.toString()) ??
                              "Endereço não cadastrado",
                        ),
                      )
                    ],
                  ),
                ))
          ],
        ));
  }
}
