import 'package:apus_drones_mobile/constants/UserType.dart';
import 'package:apus_drones_mobile/constants/Constants.dart';
import 'package:apus_drones_mobile/models/PartnerModel.dart';
import 'package:apus_drones_mobile/models/ProductModel.dart';
import 'package:apus_drones_mobile/screens/CustomerProductDetailScreen.dart';
import 'package:apus_drones_mobile/services/ProductService.dart';
import 'package:apus_drones_mobile/utils/money.dart';
import 'package:apus_drones_mobile/widgets/AddToCart.dart';
import 'package:apus_drones_mobile/widgets/BotNavBar.dart';
import 'package:flutter/material.dart';

import '../Appbar.dart';
import '../../widgets/Searchbar.dart';

class ListOfProducts extends StatefulWidget {
  final PartnerModel partner;
  const ListOfProducts(this.partner, {Key? key}) : super(key: key);

  @override
  _ListOfProductsState createState() => _ListOfProductsState(partner);
}

class _ListOfProductsState extends State<ListOfProducts> {
  PartnerModel partner = new PartnerModel(id: 0, name: "", avatarUrl: "");
  List<ProductModel> products = [];

  ProductService service = new ProductService();

  _fetch() {
    service.getProductsByPartner(partner).then((r) => this.setState(() {
          products = r;
        }));
  }

  _ListOfProductsState(PartnerModel partner) {
    this.partner = partner;
    _fetch();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: Appbar(
        title: "Produtos - ${partner.name}",
      ),
      backgroundColor: Colors.white,
      body: Column(
        children: [
          Searchbar(),
          Expanded(
              child: SingleChildScrollView(
            child: getColumnsImageWidgets(),
          ))
        ],
      ),
      bottomNavigationBar: BotNavBar(role: UserType.CUSTOMER),
    );
  }

  Column getColumnsImageWidgets() {
    List<Widget> list = [];

    list.add(Text(
      'Produtos',
      style: TextStyle(fontSize: 20, fontWeight: FontWeight.bold),
    ));
    for (var i = 0; i < products.length; i += 2) {
      list.add(
        Padding(
          padding: EdgeInsets.fromLTRB(2, 30, 2, 0.0),
          child: Row(
            mainAxisAlignment: MainAxisAlignment.spaceEvenly,
            children: [getRowChildren(i), getRowChildren(i + 1)],
          ),
        ),
      );
    }

    return new Column(children: list);
  }

  Row getRowChildren(int i) {
    List<Widget> list = [];
    if (i == products.length) {
      return Row(
          mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: list);
    }

    list.add(Card(
        elevation: 6,
        child: InkWell(
            onTap: () => Navigator.push(
                  context,
                  MaterialPageRoute(
                      builder: (context) => CustomerProductDetailScreen(
                          productId: products[i].id)),
                ),
            child: Container(
                decoration: BoxDecoration(color: Colors.white),
                child: Column(
                  children: [
                    Padding(
                      padding: EdgeInsets.all(10),
                      child: Text(
                        products[i].name,
                        style: TextStyle(
                            fontWeight: FontWeight.bold, fontSize: 16),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.all(10),
                      child: Text(
                        partner.name,
                        style: TextStyle(
                            fontWeight: FontWeight.bold, fontSize: 16),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.all(10),
                      child: Text(
                        convertNumToReais(products[i].price),
                        style: TextStyle(
                            fontWeight: FontWeight.bold, fontSize: 16),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.all(20),
                      child: Container(
                        width: 140.0,
                        height: 140.0,
                        decoration: BoxDecoration(
                          shape: BoxShape.circle,
                          border: Border.all(color: Colors.black26),
                          image: DecorationImage(
                            fit: BoxFit.fill,
                            image: NetworkImage(
                                products[i].imageUrl ?? IMG_NO_PHOTO),
                          ),
                        ),
                      ),
                    ),
                    Padding(
                      padding: EdgeInsets.all(10),
                      child: Text(
                        'Ver Detalhes',
                        style: TextStyle(
                          fontWeight: FontWeight.bold,
                          fontSize: 18,
                          color: Color.fromRGBO(0, 62, 161, 1),
                        ),
                      ),
                    ),
                    Padding(
                      padding: const EdgeInsets.all(10),
                      child: AddToCart(product: products[i]),
                    )
                  ],
                )))));
    return new Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly, children: list);
  }
}
