import 'dart:async';
import 'dart:convert';

import 'package:apus_drones_mobile/assets/config.dart';
import 'package:apus_drones_mobile/models/OrderModel.dart';
import 'package:apus_drones_mobile/models/PartialOrder.dart';
import 'package:apus_drones_mobile/utils/httpHeaders.dart';
import 'package:apus_drones_mobile/models/PartnerOrderModel.dart';
import 'package:http/http.dart' as http;

class OrderService {
  Future<List<OrderModel>> myOrders({String? filtro}) async {
    final filter = filtro != null ? "?status=" + filtro : "";
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/orders/by-user$filter'),
      headers: await getHttpHeaders(),
    );
    List<dynamic> rsBody = json.decode(response.body);
    List<OrderModel> orders =
        rsBody.map((order) => OrderModel.fromJson(order)).toList();
    orders.sort((a, b) => b.createdAt.compareTo(a.createdAt));

    return orders;
  }

  Future<OrderModel?> myCart() async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/orders/cart'),
      headers: await getHttpHeaders(),
    );
    if (response.statusCode == 404) {
      return null;
    }
    if (response.statusCode != 200) {
      throw response.body;
    }

    Map<String, dynamic> rsBody = json.decode(response.body);
    OrderModel order = OrderModel.fromJson(rsBody);
    return order;
  }

  Future<http.Response> addToCart(PartialOrder order) async {
    var response = await http.post(
      Uri.parse('${Config.apiURL}/orders/cart'),
      body: json.encode(order.toJson()),
      headers: await getHttpHeaders(),
    );
    if (response.statusCode != 200) {
      throw new Error();
    }
    return response;
  }

  Future<OrderModel> getOrder(int id) async {
    http.Response response = await http.get(
      Uri.parse('${Config.apiURL}/orders/$id'),
      headers: await getHttpHeaders(),
    );

    Map<String, dynamic> rsBody = json.decode(response.body);
    OrderModel order = OrderModel.fromJson(rsBody);
    return order;
  }

  Future<PartnerOrderModel?> updateOrder(
      PartnerOrderModel orderToUpdate) async {
    var response = await http.put(Uri.parse('${Config.apiURL}/orders'),
        body: json.encode(orderToUpdate.toJson()),
        headers: await getHttpHeaders());
    if (response.statusCode != 200) {
      throw new Error();
    }
    Map<String, dynamic> responseBody = json.decode(response.body);
    return PartnerOrderModel.fromJson(responseBody);
  }

  updateCart(OrderModel cart) async {
    var response = await http.put(
      Uri.parse('${Config.apiURL}/orders'),
      body: json.encode(cart.toJson()),
      headers: await getHttpHeaders(),
    );
    if (response.statusCode != 200) {
      throw new Error();
    }
  }
}
