import 'dart:io';

import 'package:flutter/material.dart';

class PicturesGrid extends StatelessWidget {
  final List<File>? pictures;
  final List<String>? remotePicturesUrls;
  final int height;
  final void Function(dynamic)? deleteButtonAction;
  final EdgeInsetsGeometry? margin;
  final EdgeInsetsGeometry? padding;

  const PicturesGrid({
    Key? key,
    required this.pictures,
    required this.remotePicturesUrls,
    required this.height,
    this.deleteButtonAction,
    this.margin,
    this.padding,
  }) : super(key: key);

  _getImage(int index) {
    int pLen = pictures?.length ?? 0;
    int rLen = remotePicturesUrls?.length ?? 0;
    if (index >= pLen + rLen) {
      return null;
    }
    if (index >= pLen) {
      return remotePicturesUrls?[index - pLen];
    }
    return pictures?[index];
  }

  _getImageWidget(int index, int height) {
    final image = _getImage(index);
    if (image is String) {
      return Image.network(image, cacheHeight: height).image;
    }
    if (image is File) {
      return Image.file(image, cacheHeight: height).image;
    }
    throw ('Imagem não encontrada. Index $index');
  }

  @override
  Widget build(BuildContext context) {
    final _pictures = pictures;
    final _remotePicturesUrls = remotePicturesUrls;
    final _deleteButtonAction = deleteButtonAction;

    return Container(
      margin: margin,
      padding: padding,
      height: height.toDouble(),
      child: _pictures != null && _pictures.length > 0 ||
              _remotePicturesUrls != null && _remotePicturesUrls.length > 0
          ? GridView.builder(
              scrollDirection: Axis.horizontal,
              // shrinkWrap: true,
              gridDelegate: SliverGridDelegateWithMaxCrossAxisExtent(
                // crossAxisCount: 3,
                maxCrossAxisExtent: 10000,
                crossAxisSpacing: 8,
                mainAxisSpacing: 8,
              ),
              itemCount:
                  (_pictures?.length ?? 0) + (_remotePicturesUrls?.length ?? 0),
              itemBuilder: (context, index) {
                return Container(
                  alignment: Alignment.bottomRight,
                  child: IconButton(
                    padding: EdgeInsets.zero,
                    color: Colors.green,
                    icon: Icon(
                      Icons.delete,
                      color: Colors.red,
                    ),
                    onPressed: _deleteButtonAction != null
                        ? () => _deleteButtonAction(_getImage(index))
                        : null,
                  ),
                  decoration: BoxDecoration(
                    // border: Border.all(width: 1),
                    // boxShadow: [BoxShadow(color: Colors.black)],
                    image: DecorationImage(
                      fit: BoxFit.cover,
                      image: _getImageWidget(index, height),
                    ),
                  ),
                );
              })
          : SizedBox(
              height: height.toDouble(),
            ),
    );
  }
}
